@@ -1,7 +1,7 @@
 #!/usr/bin/python2
 # -*- coding: utf-8 -*-
 
-# :Id: $Id: smartquotes.py 7668 2013-06-04 12:46:30Z milde $
+# :Id: $Id: smartquotes.py 7716 2013-08-21 21:54:57Z milde $
 # :Copyright: © 2010 Günter Milde,
 #             original `SmartyPants`_: © 2003 John Gruber
 #             smartypants.py:          © 2004, 2007 Chad Miller
@@ -388,6 +388,8 @@ class smartchars(object):
               'ca-x-altquot': u'“”‘’',
               'cs':           u'„“‚‘',
               'cs-x-altquot': u'»«›‹',
+              'da':           u'»«‘’',
+              'da-x-altquot': u'„“‚‘',
               'de':           u'„“‚‘',
               'de-x-altquot': u'»«›‹',
               'de-CH':        u'«»‹›',
